@@ -1,5 +1,5 @@
 ####
-# Get the desired distribution of iRefIndex from the ftp site:
+# Get the desired distribution of iRefIndex from the web repository:
 ####
 get_irefindex = function(tax_id="All", iref_version="current", data_folder=getwd()) {
 
@@ -14,20 +14,34 @@ get_irefindex = function(tax_id="All", iref_version="current", data_folder=getwd
 
 	# 2. Get release dates and full URLs:
 	if (iref_version == "current") {
-		iref_version = "9.0"
-		release_date = "10182011"
-		url = paste("ftp://ftp.no.embnet.org/irefindex/data/current/psimi_tab/MITAB2.6/", tax_id, ".mitab.", release_date, ".txt.zip", sep="")
+		iref_version = "12.0"
+		release_date = "06062013"
+		url = paste("http://irefindex.org/download/irefindex/data/current/psi_mitab/MITAB2.6/", tax_id, ".mitab.", release_date, ".txt.zip", sep="")
 	} else {
 		if (iref_version == "7.0") {
 			release_date = "11042010"
+			url = paste("http://irefindex.org/download/irefindex/data/archive/release_", iref_version, "/psimi_tab/MITAB2.6/", tax_id, ".mitab.", release_date, ".txt.zip", sep="")
 		}
 		if (iref_version == "8.0") {
 			release_date = "01192011"
+			url = paste("http://irefindex.org/download/irefindex/data/archive/release_", iref_version, "/psimi_tab/MITAB2.6/", tax_id, ".mitab.", release_date, ".txt.zip", sep="")
 		}
 		if (iref_version == "9.0") {
 			release_date = "10182011"
+			url = paste("http://irefindex.org/download/irefindex/data/archive/release_", iref_version, "/psimi_tab/MITAB2.6/", tax_id, ".mitab.", release_date, ".txt.zip", sep="")
+		}
+		if (iref_version == "10.0") {
+			release_date = "03022013"
+			url = paste("http://irefindex.org/download/irefindex/data/archive/release_", iref_version, "/psi_mitab/MITAB2.6/", tax_id, ".mitab.", release_date, ".txt.zip", sep="")
+		}
+		if (iref_version == "11.0") {
+			release_date = "05192013"
+			url = paste("http://irefindex.org/download/irefindex/data/archive/release_", iref_version, "/psi_mitab/MITAB2.6/", tax_id, ".mitab.", release_date, ".txt.zip", sep="")
+		}
+		if (iref_version == "12.0") {
+			release_date = "06062013"
+			url = paste("http://irefindex.org/download/irefindex/data/archive/release_", iref_version, "/psi_mitab/MITAB2.6/", tax_id, ".mitab.", release_date, ".txt.zip", sep="")
 		}
-		url = paste("ftp://ftp.no.embnet.org/irefindex/data/archive/release_", iref_version, "/psimi_tab/MITAB2.6/", tax_id, ".mitab.", release_date, ".txt.zip", sep="")
 	}
 
 	# 3. Check if file already exists. Otherwise, download and save:
