@@ -5,7 +5,7 @@ select_database = function(database, MITAB_table, flag="this_database") {
 	# 1. Dataset for these databases:
 	dataset = NULL
 	for (i in database) {
-		dataset = rbind(dataset, MITAB_table[grep(i, MITAB_table$sourcedb),])
+		dataset = rbind(dataset, MITAB_table[grep(i, MITAB_table$sourcedb, ignore.case=TRUE),])
 	}
 
 	# 2. Dataset for all except these databases:
@@ -13,7 +13,7 @@ select_database = function(database, MITAB_table, flag="this_database") {
 		if (dim(dataset)[1] > 0) {
 			dataset = MITAB_table
 			for (i in database) {
-				dataset = dataset[-grep(i, dataset$sourcedb),]
+				dataset = dataset[-grep(i, dataset$sourcedb, ignore.case=TRUE),]
 			}
 		} else {
 			dataset = MITAB_table
